.. numba documentation master file, created by
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Numba
=====

Documentation for numba
------------------------

**Contents:**

.. toctree::
   :titlesonly:
   :maxdepth: 2

   userguide.rst
   types.rst
   pythonstuff.rst

**Arrays:**

.. toctree::
   :maxdepth: 2

   arrays.rst

**Interfacing with native code:**

.. toctree::
   :maxdepth: 2

   interface_c.rst

**Misc:**

.. toctree::
   :titlesonly:
   :maxdepth: 2

   pycc.rst
   type_inference.rst

**Examples:**

.. toctree::
   :titlesonly:
   :maxdepth: 2

   doctest.rst
   examples.rst

**Releases:**

.. toctree::
   :titlesonly:
   :maxdepth: 2

   releases.rst

Developer Documentation
------------------------


.. toctree::
   :titlesonly:
   :maxdepth: 1

   architecture.rst
   ir.rst
   roadmap.rst
   reference.rst


Indices and tables
------------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

